@@ -746,7 +746,7 @@ class API(api.API, metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def lr_route_add(self, router, prefix, nexthop, port=None,
                      policy='dst-ip', may_exist=False, ecmp=False,
-                     route_table=const.MAIN_ROUTE_TABLE):
+                     route_table=const.MAIN_ROUTE_TABLE, bfd=None):
         """Add a route to 'router'
 
         :param router:    The name or uuid of the router
@@ -771,6 +771,8 @@ class API(api.API, metaclass=abc.ABCMeta):
         :type ecmp:       boolean
         :param route_table: The name of route table
         :type route_table:  str
+        :param bfd:       A reference to the BFD table row.
+        :type bfd:        uuid.UUID
         returns:          :class:`Command` with RowView result
         """
 
@@ -1236,6 +1238,19 @@ class API(api.API, metaclass=abc.ABCMeta):
         :returns:    :class:`Command` with no result
         """
 
+    @abc.abstractmethod
+    def dns_set_options(self, uuid, if_exists=True, **options):
+        """Sets the 'options' field of the DNS row
+
+        :param uuid: The uuid of the DNS row to set the options with
+        :type uuid:  string or uuid.UUID
+        :param if_exists: Do not fail if the DNS row does not exist
+        :type if_exists:  boolean
+        :param options: keys and values for the DNS 'options' dict
+        :type options:  key: string, value: string
+        :returns:    :class:`Command` with no result
+        """
+
     @abc.abstractmethod
     def pg_add(self, name=None, may_exist=False, **columns):
         """Create a port group
