@@ -12,7 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 import testtools
 
 from ovsdbapp import exceptions
@@ -33,3 +34,19 @@ class TransactionTestCase(base.TestCase):
             transaction = impl_idl.OvsVsctlTransaction(mock.sentinel,
                                                        mock.Mock(), 0)
             transaction.post_commit(mock.Mock())
+
+
+class TestOvsdbIdl(base.TestCase):
+    def setUp(self):
+        super(TestOvsdbIdl, self).setUp()
+        impl_idl.OvsdbIdl.ovsdb_connection = None
+
+    def test_nested_txns(self):
+        conn = mock.MagicMock()
+        api = impl_idl.OvsdbIdl(conn, nested_transactions=False)
+        self.assertFalse(api._nested_txns)
+
+    def test_init_session(self):
+        conn = mock.MagicMock()
+        impl_idl.OvsdbIdl(conn, start=False)
+        conn.start_connection.assert_not_called()
